@@ -205,20 +205,56 @@ opts = [
                        'endpoint via multicast DNS.')),
     cfg.StrOpt('deploy_kernel',
                mutable=True,
-               help=_('Glance ID, http:// or file:// URL of the kernel of '
-                      'the default deploy image.')),
+               deprecated_for_removal=True,
+               deprecated_reason=_('Replaced by deploy_kernel_by_arch which '
+                                   'provides more configuration options.'),
+               help=_('DEPRECATED: Glance ID, http:// or file:// URL of the '
+                      'kernel of the default deploy image.')),
     cfg.StrOpt('deploy_ramdisk',
                mutable=True,
-               help=_('Glance ID, http:// or file:// URL of the initramfs of '
-                      'the default deploy image.')),
+               deprecated_for_removal=True,
+               deprecated_reason=_('Replaced by deploy_ramdisk_by_arch which '
+                                   'provides more configuration options.'),
+               help=_('DEPRECATED: Glance ID, http:// or file:// URL of the '
+                      'initramfs of the default deploy image.')),
+    cfg.DictOpt('deploy_kernel_by_arch',
+                default={},
+                mutable=True,
+                help=_('A dictionary of key-value pairs of each architecture '
+                       'with the Glance ID, http:// or file:// URL of the '
+                       'kernel of the default deploy image.')),
+    cfg.DictOpt('deploy_ramdisk_by_arch',
+                default={},
+                mutable=True,
+                help=_('A dictionary of key-value pairs of each architecture '
+                       'with the Glance ID, http:// or file:// URL of the '
+                       'initramfs of the default deploy image.')),
     cfg.StrOpt('rescue_kernel',
                mutable=True,
-               help=_('Glance ID, http:// or file:// URL of the kernel of '
-                      'the default rescue image.')),
+               deprecated_for_removal=True,
+               deprecated_reason=_('Replaced by rescue_kernel_by_arch which '
+                                   'provides more configuration options.'),
+               help=_('DEPRECATED: Glance ID, http:// or file:// URL of the '
+                      'kernel of the default rescue image.')),
     cfg.StrOpt('rescue_ramdisk',
                mutable=True,
-               help=_('Glance ID, http:// or file:// URL of the initramfs of '
-                      'the default rescue image.')),
+               deprecated_for_removal=True,
+               deprecated_reason=_('Replaced by rescue_ramdisk_by_arch which '
+                                   'provides more configuration options.'),
+               help=_('DEPRECATED: Glance ID, http:// or file:// URL of the '
+                      'initramfs of the default rescue image.')),
+    cfg.DictOpt('rescue_kernel_by_arch',
+                default={},
+                mutable=True,
+                help=_('A dictionary of key-value pairs of each architecture '
+                       'with the Glance ID, http:// or file:// URL of the '
+                       'kernel of the default rescue image.')),
+    cfg.DictOpt('rescue_ramdisk_by_arch',
+                default={},
+                mutable=True,
+                help=_('A dictionary of key-value pairs of each architecture '
+                       'with the Glance ID, http:// or file:// URL of the '
+                       'initramfs of the default rescue image.')),
     cfg.StrOpt('rescue_password_hash_algorithm',
                default='sha256',
                choices=['sha256', 'sha512'],
@@ -349,49 +385,44 @@ opts = [
                       'is a global setting applying to all requests this '
                       'conductor receives, regardless of access rights. '
                       'The concurrent clean limit cannot be disabled.')),
-    cfg.BoolOpt('disable_deep_image_inspection',
+    cfg.BoolOpt('poweroff_in_cleanfail',
                 default=False,
-                # Normally such an option would be mutable, but this is,
-                # a security guard and operators should not expect to change
-                # this option under normal circumstances.
-                mutable=False,
-                help=_('Security Option to permit an operator to disable '
-                       'file content inspections. Under normal conditions, '
-                       'the conductor will inspect requested image contents '
-                       'which are transferred through the conductor. '
-                       'Disabling this option is not advisable and opens '
-                       'the risk of unsafe images being processed which may '
-                       'allow an attacker to leverage unsafe features in '
-                       'various disk image formats to perform a variety of '
-                       'unsafe and potentially compromising actions. '
-                       'This option is *not* mutable, and '
-                       'requires a service restart to change.')),
-    cfg.BoolOpt('conductor_always_validates_images',
+                help=_('If True power off nodes in the ``clean failed`` '
+                       'state. Default False. Option may be unsafe '
+                       'when using Cleaning to perform '
+                       'hardware-transformative actions such as '
+                       'firmware upgrade.')),
+    cfg.BoolOpt('poweroff_in_servicefail',
+                default=False,
+                help=_('If True power off nodes in the ``service failed`` '
+                       'state. Default False. Option may be unsafe '
+                       'when using service to perform '
+                       'hardware-transformative actions such as '
+                       'firmware upgrade.')),
+    cfg.BoolOpt('permit_child_node_step_async_result',
                 default=False,
-                # Normally mutable, however from a security context we do want
-                # all logging to be generated from this option to be changed,
-                # and as such is set to False to force a conductor restart.
-                mutable=False,
-                help=_('Security Option to enable the conductor to *always* '
-                       'inspect the image content of any requested deploy, '
-                       'even if the deployment would have normally bypassed '
-                       'the conductor\'s cache. When this is set to False, '
-                       'the Ironic-Python-Agent is responsible '
-                       'for any necessary image checks. Setting this to '
-                       'True will result in a higher utilization of '
-                       'resources (disk space, network traffic) '
-                       'as the conductor will evaluate *all* images. '
-                       'This option is *not* mutable, and requires a '
-                       'service restart to change. This option requires '
-                       '[conductor]disable_deep_image_inspection to be set '
-                       'to False.')),
-    cfg.ListOpt('permitted_image_formats',
-                default=['raw', 'qcow2', 'iso'],
                 mutable=True,
-                help=_('The supported list of image formats which are '
-                       'permitted for deployment with Ironic. If an image '
-                       'format outside of this list is detected, the image '
-                       'validation logic will fail the deployment process.')),
+                help=_('This option allows child node steps to not error if '
+                       'the resulting step execution returned a "wait" '
+                       'state. Under normal conditions, child nodes are not '
+                       'expected to request a wait state. This option exists '
+                       'for operators to use if needed to perform specific '
+                       'tasks where this is known acceptable. Use at your'
+                       'own risk!')),
+    cfg.IntOpt('max_conductor_wait_step_seconds',
+               default=30,
+               min=0,
+               max=1800,
+               mutable=True,
+               help=_('The maximum number of seconds which a step can '
+                      'be requested to explicitly sleep or wait. This '
+                      'value should be changed sparingly as it holds a '
+                      'conductor thread and if used across many nodes at '
+                      'once can exhaust a conductor\'s resources. This'
+                      'capability has a hard coded maximum wait of 1800 '
+                      'seconds, or 30 minutes. If you need to wait longer '
+                      'than the maximum value, we recommend exploring '
+                      'hold steps.')),
 ]
 
 
